import Resource from "./resource";

export class UrlProvider {
  constructor(
    public hash: string,
    public hashFormat: string,
    public url: Resource,
  ) {}
}

export class ModrinthProvider extends UrlProvider {
  constructor(
    hash: string,
    hashFormat: string,
    url: Resource,
    public modId: string,
    public versionId: string,
  ) {
    super(hash, hashFormat, url);
  }
}

export class GitHubProvider extends UrlProvider {
  constructor(
    hash: string,
    hashFormat: string,
    url: Resource,
    public branch: string,
    public regex: string,
    public slug: string,
    public tag: string,
  ) {
    super(hash, hashFormat, url);
  }
}

export class CurseForgeProvider extends UrlProvider {
  constructor(
    hash: string,
    hashFormat: string,
    public mode: string,
    public fileId: number,
    public projectId: number,
  ) {
    super(
      hash,
      hashFormat,
      new Resource(
        `https://www.curseforge.com/api/v1/mods/${projectId}/files/${fileId}/download`,
      ),
    );
  }
}
